@@ -42,7 +42,7 @@ class SearchableSnapshotsClient(NamespacedClient):
         """
         Retrieve node-level cache statistics about searchable snapshots.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/searchable-snapshots-apis.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/searchable-snapshots-apis.html>`_
 
         :param node_id: A comma-separated list of node IDs or names to limit the returned
             information; use `_local` to return information from the node you're connecting
@@ -104,7 +104,7 @@ class SearchableSnapshotsClient(NamespacedClient):
         """
         Clear the cache of searchable snapshots.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/searchable-snapshots-apis.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/searchable-snapshots-apis.html>`_
 
         :param index: A comma-separated list of index names
         :param allow_no_indices: Whether to ignore if a wildcard indices expression resolves
@@ -166,7 +166,7 @@ class SearchableSnapshotsClient(NamespacedClient):
         """
         Mount a snapshot as a searchable index.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/searchable-snapshots-api-mount-snapshot.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/searchable-snapshots-api-mount-snapshot.html>`_
 
         :param repository: The name of the repository containing the snapshot of the
             index to mount
@@ -235,7 +235,7 @@ class SearchableSnapshotsClient(NamespacedClient):
         """
         Retrieve shard-level statistics about searchable snapshots.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/master/searchable-snapshots-apis.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/searchable-snapshots-apis.html>`_
 
         :param index: A comma-separated list of index names
         :param level: Return stats aggregated at cluster, index or shard level
