@@ -41,7 +41,7 @@ class TransformClient(NamespacedClient):
         """
         Deletes an existing transform.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/delete-transform.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/delete-transform.html>`_
 
         :param transform_id: Identifier for the transform.
         :param force: If this value is false, the transform must be stopped before it
@@ -94,7 +94,7 @@ class TransformClient(NamespacedClient):
         """
         Retrieves configuration information for transforms.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/get-transform.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/get-transform.html>`_
 
         :param transform_id: Identifier for the transform. It can be a transform identifier
             or a wildcard expression. You can get information for all transforms by using
@@ -156,7 +156,7 @@ class TransformClient(NamespacedClient):
         """
         Retrieves usage information for transforms.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/get-transform-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/get-transform-stats.html>`_
 
         :param transform_id: Identifier for the transform. It can be a transform identifier
             or a wildcard expression. You can get information for all transforms by using
@@ -219,9 +219,11 @@ class TransformClient(NamespacedClient):
         """
         Previews a transform.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/preview-transform.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/preview-transform.html>`_
 
-        :param transform_id: The id of the transform to preview.
+        :param transform_id: Identifier for the transform to preview. If you specify
+            this path parameter, you cannot provide transform configuration details in
+            the request body.
         :param description: Free text description of the transform.
         :param dest: The destination for the transform.
         :param frequency: The interval between checks for changes in the source indices
@@ -314,7 +316,7 @@ class TransformClient(NamespacedClient):
         """
         Instantiates a transform.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/put-transform.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/put-transform.html>`_
 
         :param transform_id: Identifier for the transform. This identifier can contain
             lowercase alphanumeric characters (a-z and 0-9), hyphens, and underscores.
@@ -392,6 +394,50 @@ class TransformClient(NamespacedClient):
             "PUT", __path, params=__query, headers=__headers, body=__body
         )
 
+    @_rewrite_parameters()
+    def reset_transform(
+        self,
+        *,
+        transform_id: str,
+        error_trace: t.Optional[bool] = None,
+        filter_path: t.Optional[
+            t.Union[str, t.Union[t.List[str], t.Tuple[str, ...]]]
+        ] = None,
+        force: t.Optional[bool] = None,
+        human: t.Optional[bool] = None,
+        pretty: t.Optional[bool] = None,
+    ) -> ObjectApiResponse[t.Any]:
+        """
+        Resets an existing transform.
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/reset-transform.html>`_
+
+        :param transform_id: Identifier for the transform. This identifier can contain
+            lowercase alphanumeric characters (a-z and 0-9), hyphens, and underscores.
+            It has a 64 character limit and must start and end with alphanumeric characters.
+        :param force: If this value is `true`, the transform is reset regardless of its
+            current state. If it's `false`, the transform must be stopped before it can
+            be reset.
+        """
+        if transform_id in SKIP_IN_PATH:
+            raise ValueError("Empty value passed for parameter 'transform_id'")
+        __path = f"/_transform/{_quote(transform_id)}/_reset"
+        __query: t.Dict[str, t.Any] = {}
+        if error_trace is not None:
+            __query["error_trace"] = error_trace
+        if filter_path is not None:
+            __query["filter_path"] = filter_path
+        if force is not None:
+            __query["force"] = force
+        if human is not None:
+            __query["human"] = human
+        if pretty is not None:
+            __query["pretty"] = pretty
+        __headers = {"accept": "application/json"}
+        return self.perform_request(  # type: ignore[return-value]
+            "POST", __path, params=__query, headers=__headers
+        )
+
     @_rewrite_parameters()
     def start_transform(
         self,
@@ -408,7 +454,7 @@ class TransformClient(NamespacedClient):
         """
         Starts one or more transforms.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/start-transform.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/start-transform.html>`_
 
         :param transform_id: Identifier for the transform.
         :param timeout: Period to wait for a response. If no response is received before
@@ -453,7 +499,7 @@ class TransformClient(NamespacedClient):
         """
         Stops one or more transforms.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/stop-transform.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/stop-transform.html>`_
 
         :param transform_id: Identifier for the transform. To stop multiple transforms,
             use a comma-separated list or a wildcard expression. To stop all transforms,
@@ -532,11 +578,9 @@ class TransformClient(NamespacedClient):
         """
         Updates certain properties of a transform.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/update-transform.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/update-transform.html>`_
 
-        :param transform_id: Identifier for the transform. This identifier can contain
-            lowercase alphanumeric characters (a-z and 0-9), hyphens, and underscores.
-            It must start and end with alphanumeric characters.
+        :param transform_id: Identifier for the transform.
         :param defer_validation: When true, deferrable validations are not run. This
             behavior may be desired if the source index does not exist until after the
             transform is created.
@@ -609,7 +653,7 @@ class TransformClient(NamespacedClient):
         """
         Upgrades all transforms.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/current/upgrade-transforms.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/upgrade-transforms.html>`_
 
         :param dry_run: When true, the request checks for updates but does not run them.
         :param timeout: Period to wait for a response. If no response is received before
